# Pandas utils module

## Functions

::: iso_week_date.pandas_utils.datetime_to_isoweek
    options:
        show_root_full_path: true
        show_root_heading: true
        heading_level: 3

::: iso_week_date.pandas_utils.datetime_to_isoweekdate
    options:
        show_root_full_path: true
        show_root_heading: true
        heading_level: 3

::: iso_week_date.pandas_utils.isoweek_to_datetime
    options:
        show_root_full_path: true
        show_root_heading: true
        heading_level: 3

::: iso_week_date.pandas_utils.isoweekdate_to_datetime
    options:
        show_root_full_path: true
        show_root_heading: true
        heading_level: 3

::: iso_week_date.pandas_utils.is_isoweek_series
    options:
        show_root_full_path: true
        show_root_heading: true
        heading_level: 3

::: iso_week_date.pandas_utils.is_isoweekdate_series
    options:
        show_root_full_path: true
        show_root_heading: true
        heading_level: 3

## Series extension

::: iso_week_date.pandas_utils.SeriesIsoWeek
    options:
        show_root_full_path: true
        show_root_heading: true
        heading_level: 3
